summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/storage/mymoneydatabasemgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/storage/mymoneydatabasemgr.h')
-rw-r--r--kmymoney2/mymoney/storage/mymoneydatabasemgr.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/mymoney/storage/mymoneydatabasemgr.h b/kmymoney2/mymoney/storage/mymoneydatabasemgr.h
index e146a70..5135ca4 100644
--- a/kmymoney2/mymoney/storage/mymoneydatabasemgr.h
+++ b/kmymoney2/mymoney/storage/mymoneydatabasemgr.h
@@ -82,15 +82,15 @@ public:
/**
* This method is used to add one account as sub-ordinate to another
- * (tqparent) account. The objects that are passed will be modified
+ * (parent) account. The objects that are passed will be modified
* accordingly.
*
* An exception will be thrown upon error conditions.
*
* @param tqparent tqparent account the account should be added to
* @param account the account to be added
*/
- virtual void addAccount(MyMoneyAccount& tqparent, MyMoneyAccount& account);
+ virtual void addAccount(MyMoneyAccount& parent, MyMoneyAccount& account);
/**
* This method is used to create a new payee
@@ -325,9 +325,9 @@ public:
* An exception will be thrown upon error conditions.
*
* @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
*/
- virtual void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& tqparent);
+ virtual void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& parent);
/**
* This method is used to remove a transaction from the transaction
@@ -82,15 +82,15 @@ public:
* An exception will be thrown upon error conditions.
*
- * @param tqparent tqparent account the account should be added to
+ * @param parent parent account the account should be added to
* @param account the account to be added
*/
@@ -325,9 +325,9 @@ public:
*
* @param account MyMoneyAccount reference to account to be re-parented
- * @param tqparent MyMoneyAccount reference to new tqparent account
+ * @param parent MyMoneyAccount reference to new parent account
*/